.. :changelog:

History
-------

0.1.1 (2016-11-30)
++++++++++++++++++

* Added editing online support
* Fixed bugs
* Added offline badge at the bottom

0.1.0 (2016-11-27)
++++++++++++++++++

* First release on PyPI.
